@@ -188,7 +188,7 @@ GeomLabelS <-
                                                          ggplot2::alpha(default.colour, box.colour.alpha)),
                                                 fill = alpha(row$fill, box.fill.alpha),
                                                 # lwd = (if (row$linewidth == 0) 1 else row$linewidth) * .pt, # mm -> points (as in 'ggplot2')
-                                                lwd = (if (row$linewidth == 0) 1 else row$linewidth) * .stroke, # mm -> stroke (correct)
+                                                lwd = (if (row$linewidth == 0) 0.5 else row$linewidth) * ggplot2::.stroke, # mm -> stroke (correct)
                                                 lty = row$linetype
                                               )
                        )
@@ -212,7 +212,7 @@ GeomLabelS <-
                                                     ifelse(any(colour.target %in% c("all", "segment")),
                                                            ggplot2::alpha(row$colour, segment.alpha),
                                                            ggplot2::alpha(default.colour, segment.alpha)),
-                                                  lwd = (if (segment.linewidth == 0) 1 else segment.linewidth) * .stroke),
+                                                  lwd = (if (segment.linewidth == 0) 0.5 else segment.linewidth) * ggplot2::.stroke),
                                                 name = paste("text.s.segment", row$group, row.idx, sep = "."))
                          }
                          all.grobs <- grid::gList(all.grobs, segment.grob, user.grob)
